==> pfs-utils-gui-2017.10-10-any.pkg.tar.xz: usr/local/bin/pacman2pfs.sh <==
#!/bin/ash
v=150127
[ ! -f /var/lib/pacman/sync/core.db ] && wt "sudo pacman -Syy" "Обновление базы пакетов"

f="`yad --window-icon=gtk-find --center  --title="pacman2pfs.sh v. $v"  --XXXimage-on-top --image="pet48" \
    --entry --entry-label= --text "<b>Установка пакета или создание из него модуля</b>
Введите (по англ.) часть имени или описания пакета"`"

ER(){ [ ! "$1" ] && ntf -a "Ничего не выбрано" && exit ; }
ER "$f"

p="$(ntf -l "`pacman -Ss "$f" |sed ':a; N; $!ba; s/\n //g'`" "Результаты поиска '$f' в подключенных репозиториях
</b>Выберите пакет<b>")"
p="`echo "$p" |awk '{print $1}'`"
ER "$p"

INST(){
e="`echo y| sudo pacman -S "$p" --force 2>&1`"
[ "$?" = "0" ] && ntf -w "Пакет $p успешно установлен" "<small>$e</small>" || ntf -a "Ошибка" "$e"
}
#INST

PFS(){
p="`echo "$p" |awk -F "/" '{print $2}'`"
cd ~
#    read -p "Очистить кэш пакетов? [Y/n] " y
sudo rm /var/cache/pacman/pkg/* #pacman -Sc --noconfirm
#e="`defaultterminal -e echo y| sudo pacman2pfs -n "$p"`"
#defaultterminal 
urxvt -e sudo pacman2pfs -n "$p"
d="`ls -1d ~/$p-*|head -1`"
echo d="$d"
if [ "$d" ] ;then
    ntf -q "Пакеты скачаны в /var/cache/pacman/pkg 
Распакованы в $d" "В $d\_DEV находится файлы нужные для компиляции.

Сжать в модуль?"
    if [ "$?" = "0" ] ;then
    sudo rm -R "$d/var" 
    wt "sudo mkpfs "$d"" #&& sudo rm -R "$d"
    fi
fi
##m="`ls -1 ~/$p-*.pfs`"
##[ -f "$m" ] && ntf -w "Модуль $m успешно создан" #|| er="`ntf -q "Ошибка" "Вывести подробности?"`"
#[ "$er" = "0" ] && echo "$e" |leafpad
}
#PFS
ap="Установить пакет" ; am="Создать из пакета модуль"
a="`ntf -l "$ap|$am" "Выберите"`"
ER "$a"
[ "$a" = "$ap" ] && INST || PFS

==> pfs-utils-gui-2018.12-04-any.pkg.tar.xz: usr/local/bin/pacman2pfs.sh <==
#!/bin/ash
v=180407 #sfs
[ ! -f /var/lib/pacman/sync/core.db ] && wt "sudo pacman -Syy" "Обновление базы пакетов"

f="`yad --window-icon=gtk-find --center  --title="pacman2pfs.sh v. $v"  --XXXimage-on-top --image="pet48" \
    --entry --entry-label= --text "<b>Установка пакета или создание из него модуля</b>

При создании модуля - vаксимально отключите все небазовые модули. Иначе Ваш модуль без них работать не будет
Подключите зависимые модули (например, gtk или qt). Иначе Ваш модуль получится большим.

Введите (по англ.) часть имени или описания пакета"`" || exit 1

ER(){ [ ! "$1" ] && ntf -a "Ничего не выбрано" && exit ; }
ER "$f"

p="$(ntf -l "`pacman -Ss "$f" |sed ':a; N; $!ba; s/\n //g'`" "Результаты поиска '$f' в подключенных репозиториях
</b>Выберите пакет<b>")"
p="`echo "$p" |awk '{print $1}'`"
ER "$p"

INST(){
e="`echo y| sudo pacman -S "$p" --force 2>&1`"
[ "$?" = "0" ] && ntf -w "Пакет $p успешно установлен" "<small>$e</small>" || ntf -a "Ошибка" "$e"
}
#INST

PFS(){
p="`echo "$p" |awk -F "/" '{print $2}'`"
cd ~
#    read -p "Очистить кэш пакетов? [Y/n] " y
sudo rm /var/cache/pacman/pkg/* #pacman -Sc --noconfirm
#e="`defaultterminal -e echo y| sudo pacman2pfs -n "$p"`"
#defaultterminal 
urxvt -e sudo pacman2pfs -n "$p"
d="`ls -1d ~/$p*|head -1`"
echo d="$d"
if [ "$d" ] ;then
    ntf -q "Пакеты скачаны в /var/cache/pacman/pkg 
Распакованы в $d" "В $d\_DEV находится файлы нужные для компиляции.

Сжать в модуль?"
    if [ "$?" = "0" ] ;then
    sudo rm -R "$d/var" 
    wt "sudo mkpfs "$d"" #&& sudo rm -R "$d"
    defaultfilemanager "`dirname "$d"`" &
    fi
fi
##m="`ls -1 ~/$p-*.pfs`"
##[ -f "$m" ] && ntf -w "Модуль $m успешно создан" #|| er="`ntf -q "Ошибка" "Вывести подробности?"`"
#[ "$er" = "0" ] && echo "$e" |leafpad
}
#PFS
ap="Установить пакет" ; am="Создать из пакета модуль"
a="`ntf -l "$ap|$am" "Выберите"`"
ER "$a"
[ "$a" = "$ap" ] && INST || PFS
